@@ -56,8 +56,10 @@ test_that("the wrapper behaves as expected", {
   expect_equal(nrow(arrivals_res), 10)
   expect_equal(nrow(attributes), 10)
   expect_equal(nrow(resources), 21)
+  expect_equal(env %>% get_sources(), c("dummy", "rollback"))
   expect_error(env %>% get_n_generated("asdf"))
   expect_equal(env %>% get_n_generated("dummy"), 10)
+  expect_equal(env %>% get_resources(), "server")
   expect_error(env %>% get_capacity("asdf"))
   expect_equal(env %>% get_capacity("server"), 1)
   expect_error(env %>% get_queue_size("asdf"))
